
# ----------------------- ipmisc -----------------------------------

#' @export
#' @importFrom ipmisc specify_decimal_p
ipmisc::specify_decimal_p

#' @export
#' @importFrom ipmisc signif_column
ipmisc::signif_column

#' @export
#' @importFrom ipmisc long_to_wide_converter
ipmisc::long_to_wide_converter

# ----------------------- tidyverse -------------------------------------

#' @export
#' @importFrom ipmisc "%>%"
ipmisc::`%>%`

#' @export
#' @importFrom ipmisc "%<>%"
ipmisc::`%<>%`

#' @export
#' @importFrom ipmisc "%$%"
ipmisc::`%$%`

#' @export
#' @importFrom ipmisc "%<-%"
ipmisc::`%<-%`

#' @export
#' @importFrom rlang "%||%"
rlang::`%||%`

#' @export
#' @importFrom rlang "%|%"
rlang::`%|%`

#' @export
#' @importFrom rlang ":="
rlang::`:=`

#' @export
#' @importFrom ipmisc tibble
ipmisc::tibble

#' @export
#' @importFrom ipmisc as_tibble
ipmisc::as_tibble

# ----------------------- metaBMA -------------------------------------

#' @export
#' @importFrom metaBMA prior
metaBMA::prior
